@@ -1,21 +1,14 @@
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 
-from ..forms import CreditCardPaymentForm
+from ..forms import CreditCardPaymentFormWithName
 from .. import get_credit_card_issuer
 
 
-class PaymentForm(CreditCardPaymentForm):
+class PaymentForm(CreditCardPaymentFormWithName):
 
     VALID_TYPES = ['visa', 'mastercard', 'discover', 'amex']
 
-    name = forms.CharField(label=_('Name on Credit Card'), max_length=128)
-
-    def __init__(self, *args, **kwargs):
-        super(PaymentForm, self).__init__(*args, **kwargs)
-        self.fields.keyOrder.remove('name')
-        self.fields.keyOrder.insert(0, 'name')
-
     def clean(self):
         cleaned_data = super(PaymentForm, self).clean()
 
